import * as Types from '../../types/types';
/**
 * @TODO: Clean up addTriggerAction
 */
/**
 * This class holds methods related to the wide term "events"
 *
 * This includes creating a simple action in BetterTouchTool, as well as
 * creating advanced event listeners which are going to be evaluated on btt-node-server side
 */
export default class EventManager {
    private config;
    private defaultComment;
    private namespace;
    /**
     * Initializes the event manager with specific btt config
     * @param config
     */
    constructor(config: Types.AppConfig);
    /**
     * Adds event listener to BTT. Keep in mind this is persistent, so if you call this method twice,
     * two entries will be added to BTT. Closing the browser / node process won't make the listeners die
     *
     * @param eventType string, created from action enum identifier
     * @param cb IEventParameter
     */
    addTriggerAction(eventType: string, cb: Types.EventCallback): void;
    /**
     * Removes event listener
     *
     * @param eventType string, created from action enum identifier
     * @param cb
     */
    removeTriggerAction(eventType: string, cb: Types.EventCallback): void;
    /**
     *
     * @param eventType
     * @param cb
     */
    addEventListener(eventType: string, cb: Types.EventCallback): void;
    /**
     * Removes the trigger that'd make a specific request to the btt-node-server
     *
     * @param eventType event that'd trigger the action
     * @param cb callback that you want to take off from the event
     */
    removeEventListener(eventType: string, cb: Types.EventCallback): void;
    /**
     * Runs the code in the current btt instance
     * @param code code to be run
     */
    private executeScript;
    /**
     * Shows a notification when user is invoking a valid, btt-node-server event
     */
    private showNotification;
    /**
     * Generates uuid for specific event / action trigger
     * @param args
     */
    private generateUUID;
    /**
     * Generates a payload, later interpreted by btt-node-server
     *
     * @param bttConfig config of certain btt instance
     * @param callback function to invoke
     */
    private generatePayload;
    /**
     * Returns the trigger class proprerty, required for trigger actions to work
     *
     * @param value
     */
    private getTriggerClassProperty;
    /**
     * Builds a JSON out of given array of action objects
     *
     * @param actions
     */
    private buildActionSequence;
    /**
     * Builds trigger action, that can be added to BTT (event listener like)
     *
     * @param eventName
     * @param batchAction
     * @param options
     */
    private buildTriggerAction;
}
