import * as Types from '../types/types';
export declare class Trigger {
    uuid: string;
    private name;
    private config;
    /**
     * Constructs the Trigger instance, sets the uuid and name for further calls
     */
    constructor(config: Types.AppConfig, triggerConfig: Types.TriggerConfig);
    /**
     * Calls the given trigger. Based on the data it was constructed with
     * the method of invoke varies
     */
    invoke(): Promise<Types.CallResult>;
    /**
     * Updates the trigger data with given JSON
     */
    update(json: Types.BttPayload): Promise<Types.CallResult>;
    /**
     * Removes current trigger
     */
    delete(): Promise<Types.CallResult>;
    /**
     * Calls BTT with given payload using widget context
     * @TODO may be made reusable
     * @param mode
     * @param payload
     */
    private callBTTWithContext;
}
/**
 * Creates an instances of Trigger with specified config
 */
export declare class FTrigger {
    private config;
    constructor(config: Types.AppConfig);
    /**
     * Deletes a trigger of given uuid
     * @param uuid
     */
    delete(uuid: string): Promise<Types.CallResult>;
    /**
     * Creates a new trigger
     * @param config
     */
    create(json: Types.TriggerConfig): Promise<Trigger>;
    /**
     * Returns existing trigger
     * @param config
     */
    get(config: Types.TriggerConfig): Trigger;
    /**
     * Triggers an action / trigger of specified json
     */
    invoke(json: Types.BttPayload): Promise<Types.CallResult>;
    /**
     * Calls BTT with given payload using widget context
     * @TODO may be made reusable
     * @param mode
     * @param payload
     */
    private callBTTWithContext;
}
