import { EventCategory } from './enum';
export interface KeyDefinition {
    key: string;
    code: number;
    locationMask?: number;
    modifierValue?: number;
}
export interface CallResult {
    time: number;
    status: number;
    value: any;
    note?: string;
}
export declare type ChainResponse = CallResult;
export declare type ChainEntry = () => Promise<CallResult>;
export interface AppConfig {
    domain: string;
    port: number;
    protocol: string;
    sharedKey?: string;
    version?: string;
    eventServer?: EventServerDefinition;
    nodeBinaryPath?: string;
    blacklist?: string[];
    silent?: boolean;
}
export interface EventServerDefinition {
    domain: string;
    port: number;
}
export interface TriggerConfig {
    uuid?: string;
    name?: string;
}
export interface WidgetConfig {
    uuid: string;
    default: Function;
}
export interface ActionRequirements {
    min: string;
    max?: string;
    buggy?: string[];
    name?: string;
}
export interface ActionConfig {
    requirements: ActionRequirements;
    name: string;
}
export interface ShowHUDConfig {
    title?: string;
    content?: string;
    duration?: number;
    background?: string;
    direction?: number;
}
export interface SendTextConfig {
    text: string;
    moveCursorLeft?: number;
}
export interface MoveMouseConfig {
    x: number;
    y: number;
    relativeTo?: number;
}
export interface ShowWebViewConfig {
    width: number;
    height: number;
    name: string;
    x?: number;
    y?: number;
    url?: string;
    html?: string;
    config?: FloatingWebViewConfig;
}
export interface FloatingWebViewConfig {
    cache?: boolean;
    closeOnClickOut?: boolean;
    whiteBackground?: boolean;
    closeOnBrowserOpen?: boolean;
    showButtons?: boolean;
}
export declare type ActionJSON = Partial<AppPayload>;
export interface EventParameter {
    actions: ActionJSON[];
    comment: string;
    additionalData: Partial<AppPayload>;
    requiredModifierKeys: ('fn' | 'cmd' | 'alt' | 'ctrl' | 'shift')[];
    config: BttPayload;
}
export interface ShowNotificationConfig {
    title: string;
    content: string;
}
export interface WidgetCreateConfig {
    name: string;
    mode: 'node' | 'bash';
    path: string;
    alwaysShow: boolean;
    script: string;
    appearance: {
        iconHeight: number;
        iconWidth: number;
        padding: number;
        freeSpaceAfterButton: number;
        buttonColor: string;
        alternateBackgroundColor: string;
    };
}
export interface Class<T> {
    new (config: AppConfig, ...args: any[]): T;
}
export declare type KeyCombo = string;
export declare type AppPayload = Record<string, any>;
export declare type BttPayload = Record<string, any>;
export interface EventTrigger {
    id: number;
    category: EventCategory;
    name: string;
    notices?: NoticeMessage[];
}
export interface NoticeMessage {
    text: string;
    data?: Partial<AppPayload>;
}
export declare type EventCallback = (e: EventParameter) => void;
/**
 * ETR - EventTriggerRequirements (Additional options for some triggers)
 */
export interface ETRNamedTrigger {
    triggerName: string;
}
export interface ETRLaunchingOnSerialNumber {
    machineSerialNumber: string;
}
export interface ETRMoveMouseToCorner {
    delayBeforeTriggering: number;
    allowDragging: 0 | 1;
}
export declare type ETRMoveMouseToTopLeftCorner = ETRMoveMouseToCorner;
export declare type ETRMoveMouseToTopRightCorner = ETRMoveMouseToCorner;
export declare type ETRMoveMouseToBottomLeftCorner = ETRMoveMouseToCorner;
export declare type ETRMoveMouseToBottomRightCorner = ETRMoveMouseToCorner;
export interface ETRRecievedDistributedNotificationWithName {
    distributedNotificationName: string;
}
export declare enum BTTEndpoint {
    WIDGET_UPDATE = "update_touch_bar_widget",
    WIDGET_REFRESH = "refresh_widget",
    WIDGET_DELETE = "delete_trigger",
    WIDGET_CLICK = "execute_assigned_actions_for_trigger",
    WIDGET_CREATE = "add_new_trigger",
    TRIGGER_UPDATE = "update_trigger",
    TRIGGER_INVOKE = "execute_assigned_actions_for_trigger",
    TRIGGER_NAMED_INVOKE = "trigger_named",
    TRIGGER_DELETE = "delete_trigger",
    TRIGGER_CREATE = "add_new_trigger",
    TRIGGER_JSON = "trigger_action"
}
